function loadScriptsSequentially(scripts, index = 0) {
    if (index < scripts.length) {
        const script = document.createElement('script');
        script.src = scripts[index];
        script.onload = () => loadScriptsSequentially(scripts, index + 1);
        document.head.appendChild(script);
    }
}

// load language
let currentLanguage = 'en-GB';
const scripts = ['/js/language.js'];
loadScriptsSequentially(scripts);

function getLangText(key) {
    if (typeof languageTexts === 'undefined') {
        loadScriptsSequentially(scripts, 0);
        setTimeout(getLangText(key), 100); // Retry after a delay
        return;
    }
    return languageTexts[currentLanguage][key];
}

function updateLanguageTexts() {
    if (typeof languageTexts === 'undefined') {
        loadScriptsSequentially(scripts, 0);
        setTimeout(updateLanguageTexts, 100); // Retry after a delay
        return;
    }
    const elements = document.querySelectorAll('span.lng');
    elements.forEach(element => {
        const key = element.id;
        element.textContent = getLangText(key);
    });
    const elementsGauge = document.querySelectorAll('div.GaugeMeter');
    elementsGauge.forEach(elementsGauge => {
        const key = elementsGauge.id;
        elementsGauge.setAttribute('data-label', getLangText(key));
    });
}

fetch('/info')
    .then(response => response.json())
    .then(data => {
        currentLanguage = data.interface.language || 'en-GB';
        console.log('Current language:', currentLanguage);
        updateLanguageTexts();
    })
    .catch(error => console.error('Error fetching language info:', error));

document.addEventListener('DOMContentLoaded', () => {
    if(typeof performLoadAbout !== 'undefined'){
        const scripts2 = ['/js/about.js'];
        loadScriptsSequentially(scripts2);
    }
    
    updateLanguageTexts();
});

function togglePasswordVisibility(id, iconID) {
    const passwordInput = document.getElementById(id);
    const iconShow = document.getElementById(iconID + "_icon_show");
    const iconHide = document.getElementById(iconID + "_icon_hide");
    if (passwordInput.getAttribute('type') === 'password') {
        passwordInput.setAttribute('type', 'text');
        iconShow.style.display = 'inline';
        iconHide.style.display = 'none';
    } else {
        passwordInput.setAttribute('type', 'password');
        iconHide.style.display = 'inline';
        iconShow.style.display = 'none';
    }
}
