#!/bin/bash

data_dir_name="data_$(date +%Y%m%d_%H%M%S)"
mkdir -p "$data_dir_name"

chmod +x ./MacOS/esptool
chmod +x ./MacOS/mklittlefs

# Read the flash memory and save it to littlefs.bin
./MacOS/esptool --chip esp32s2 --baud 460800 --before default_reset --after hard_reset read_flash 0x370000 0x80000 $data_dir_name/fs.bin
if [ $? -ne 0 ]; then
    echo "Error: Failed to read flash memory."
    exit 1
fi

# Extract the contents of littlefs.bin using mklittlefs
./MacOS/mklittlefs -u ./$data_dir_name/ext_data -b 4096 -p 256 -s 0x80000 $data_dir_name/fs.bin
if [ $? -ne 0 ]; then
    echo "Error: Failed to extract littlefs memory."
    exit 2
fi

# Copy the extracted contents to new_data
mkdir -p "$data_dir_name/new_data"
cp -R "FS/" "$data_dir_name/new_data"
cp -R "$data_dir_name/ext_data/settings/" "$data_dir_name/new_data/settings/"

# Copy original FW to data folder and create a new littlefs.bin
mkdir -p "$data_dir_name/FW"
cp -R "FW/" "$data_dir_name/FW"
./MacOS/mklittlefs -c ./$data_dir_name/new_data -b 4096 -p 256 -s 0x80000 $data_dir_name/FW/littlefs.bin
if [ $? -ne 0 ]; then
    echo "Error: Failed to pack littlefs memory."
    exit 3
fi

./MacOS/esptool --chip esp32s2 --baud 460800  --before default_reset --after hard_reset write_flash  -z --flash_mode dio --flash_freq 80m --flash_size 4MB 0x1000 $data_dir_name/FW/bootloader.bin 0x8000 $data_dir_name/FW/partitions.bin 0xe000 $data_dir_name/FW/boot_app0.bin 0x10000 $data_dir_name/FW/firmware.bin 0x370000 $data_dir_name/FW/littlefs.bin

if [ $? -eq 137 ]; then
    echo ""
    echo " --- Permission denied. Please check your permissions and try again. --- "
    echo "  1) open settings"
    echo "  2) select Privacy and Security"
    echo "  3) then click on Allow Anyway for esptool"
    echo "  4) run the script again"
    echo ""
fi

