@echo off
setlocal enabledelayedexpansion

for /f "tokens=2 delims= " %%a in ('date /t') do set date=%%a
for /f "tokens=1 delims=:" %%a in ('time /t') do set hour=%%a
for /f "tokens=2 delims=:" %%a in ('time /t') do set minute=%%a
for /f "tokens=1-2 delims=:" %%a in ('time /t') do set second=%%b
set data_dir_name=data_%date:~8,2%%date:~3,2%%date:~0,2%_%hour%%minute%%second%
if not exist "%data_dir_name%" mkdir "%data_dir_name%"


REM Read the flash memory and save it to littlefs.bin
Windows\esptool.exe --chip esp32s2 --baud 460800 --before default_reset --after hard_reset read_flash 0x370000 0x80000 %data_dir_name%\fs.bin
if %errorlevel% neq 0 (
    echo Error: Failed to read flash memory.
    pause
    exit /b 1
)

if not exist "%data_dir_name%\fs.bin" (
    echo Error: fs.bin was not created.
    pause
    exit /b 1
)


REM Extract the contents of littlefs.bin using mklittlefs
Windows\mklittlefs.exe -u .\%data_dir_name%\ext_data -b 4096 -p 256 -s 0x80000 %data_dir_name%\fs.bin
if %errorlevel% neq 0 (
    echo Error: Failed to extract littlefs memory.
    pause
    exit /b 2
)

REM Copy the extracted contents to new_data
if not exist "%data_dir_name%\new_data" mkdir "%data_dir_name%\new_data"
xcopy /E /I /Y "FS" "%data_dir_name%\new_data"
xcopy /E /I /Y "%data_dir_name%\ext_data\*" "%data_dir_name%\new_data"

REM Copy original FW to data folder and create a new littlefs.bin
mkdir "%data_dir_name%\FW"
xcopy /E /I /Y "FW" "%data_dir_name%\FW"
Windows\mklittlefs.exe -c .\%data_dir_name%\new_data -b 4096 -p 256 -s 0x80000 %data_dir_name%\FW\littlefs.bin
if %errorlevel% neq 0 (
    echo Error: Failed to pack littlefs memory.
    pause
    exit /b 3
)

Windows\esptool.exe --chip esp32s2 --baud 460800 --before default_reset --after hard_reset write_flash -z --flash_mode dio --flash_freq 80m --flash_size 4MB 0x1000 %data_dir_name%\FW\bootloader.bin 0x8000 %data_dir_name%\FW\partitions.bin 0xe000 %data_dir_name%\FW\boot_app0.bin 0x10000 %data_dir_name%\FW\firmware.bin 0x370000 %data_dir_name%\FW\littlefs.bin

endlocal
pause